.. _github-stats:

GitHub Stats
============

GitHub stats for 2020/08/14 - 2020/09/15 (tag: v3.3.1)

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 15 issues and merged 39 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/57?closed=1>`__

The following 14 authors contributed 61 commits.

* Antony Lee
* Bruno Beltran
* David Stansby
* David Young
* Elliott Sales de Andrade
* Greg Lucas
* Jody Klymak
* johnthagen
* Jouni K. Seppänen
* Richard Sheridan
* richardsheridan
* Ryan May
* Thomas A Caswell
* Tim Hoffmann

GitHub issues and pull requests:

Pull Requests (39):

* :ghpull:`18488`: Backport PR #18483 on branch v3.3.x (DOC: reword non-monotonic cell center warning)
* :ghpull:`18483`: DOC: reword non-monotonic cell center warning
* :ghpull:`18485`: Backport PR #18475 on branch v3.3.x (BF: ensure exception caught if no kpeswitch)
* :ghpull:`18482`: Backport PR #18398 on branch v3.3.x (Warn on non-increasing/decreasing pcolor coords)
* :ghpull:`18484`: Backport PR #18458: Fix huge imshow range
* :ghpull:`18475`: BF: ensure exception caught if no kpeswitch
* :ghpull:`18458`: Fix huge imshow range
* :ghpull:`18398`: Warn on non-increasing/decreasing pcolor coords
* :ghpull:`18479`: Nbagg backports
* :ghpull:`18454`: nbagg: Use OutputArea event to trigger figure close.
* :ghpull:`18469`: Backport PR #18464 on branch v3.3.x (Remove extra stickies in barstacked histogram.)
* :ghpull:`18464`: Remove extra stickies in barstacked histogram.
* :ghpull:`18459`: Backport PR #18393 on branch v3.3.x (Fix Axis scale on twinned Axes.)
* :ghpull:`18393`: Fix Axis scale on twinned Axes.
* :ghpull:`18441`: Backport PR #18395: TkAgg bugfix: deselect buttons that are not the current _Mode
* :ghpull:`18395`: TkAgg bugfix: deselect buttons that are not the current _Mode
* :ghpull:`18380`: Backport PR #18374 on branch v3.3.x (FIX: make _reshape_2D accept pandas df with string indices)
* :ghpull:`18374`: FIX: make _reshape_2D accept pandas df with string indices
* :ghpull:`18376`: Backport PR #18298 on branch v3.3.x (Include license files in built distribution)
* :ghpull:`18375`: Backport PR #18293 on branch v3.3.x (Fix scatter3d color/linewidth re-projection)
* :ghpull:`18298`: Include license files in built distribution
* :ghpull:`18293`: Fix scatter3d color/linewidth re-projection
* :ghpull:`18361`: nbagg: Store DPI ratio on figure instead of window.
* :ghpull:`18354`: Backport PR #18352 on branch v3.3.x (Avoid triggering backend resolution during qt initial import.)
* :ghpull:`18352`: Avoid triggering backend resolution during qt initial import.
* :ghpull:`18335`: Backport PR #18322 on branch v3.3.x (Disable FH4 so that we don't require VCRUNTIME140_1.dll.)
* :ghpull:`18322`: Disable FH4 so that we don't require VCRUNTIME140_1.dll.
* :ghpull:`18333`: Backport PR #18328 on branch v3.3.x (Add missing check for None in Qt toolmanager.)
* :ghpull:`18328`: Add missing check for None in Qt toolmanager.
* :ghpull:`18309`: Backport PR #18304 on branch v3.3.x (Fix canvas redraws during motion in figures with a Button or TextBox)
* :ghpull:`18304`: Fix canvas redraws during motion in figures with a Button or TextBox
* :ghpull:`18297`: Backport PR #18288 on branch v3.3.x (FIX: check if axes is off page before repositioning title)
* :ghpull:`18288`: FIX: check if axes is off page before repositioning title
* :ghpull:`18269`: Backport PR #18266 on branch v3.3.x (Fix Path.get_extents for empty paths.)
* :ghpull:`18266`: Fix Path.get_extents for empty paths.
* :ghpull:`18263`: Backport PR #18260 on branch v3.3.x (Add parent widget to IntVar)
* :ghpull:`18260`: Add parent widget to IntVar
* :ghpull:`18253`: Backport PR #18245 on branch v3.3.x
* :ghpull:`18245`: MNT: do a better job guessing the GUI framework in use

Issues (15):

* :ghissue:`18415`: imshow with LogNorm crashes with certain inputs
* :ghissue:`18447`: nbagg: Closing a figure from the notebook does not close the python figure
* :ghissue:`18470`: interactive plots slow with matplotlib 3.3.1
* :ghissue:`18457`: Incorrect log y-scale for histogram with partitioned and barstacked data
* :ghissue:`18385`: twinx not respecting log-scale
* :ghissue:`18371`: Plotting a pandas DataFrame with string MultiIndex
* :ghissue:`18296`: LICENSE file(s) not included in published PyPI package
* :ghissue:`18287`: scatter3D assigns wrong color to points for some plot orientations
* :ghissue:`18292`: ImportError: DLL load failed with Matplotlib 3.3.1 on Windows
* :ghissue:`18327`: Tool Manager: adding buttons to toolbar fails with matplotlib version 3.3.1 using Qt backend
* :ghissue:`18324`:  Poor UI responsiveness  of 3.3.1 compared with 3.2.2 for interactive mode UI using widgets
* :ghissue:`18303`: Canvas redraws during any motion when Button is present
* :ghissue:`18283`: Automatic title placement wrong if parent axes is off the page
* :ghissue:`18254`: scatter(..., marker='') raises on drawing with mpl3.3.1
* :ghissue:`18259`: New IntVar needs a parent widget


Previous GitHub Stats
---------------------


.. toctree::
    :maxdepth: 1
    :glob:
    :reversed:

    prev_whats_new/github_stats_*
